//@line 36 "/builds/tinderbox/Fx-Mozilla1.8.0-l10n-Release/Linux_2.4.21-37.EL_Depend/mozilla/browser/locales/../../../l10n/ga-IE/browser/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Mozilla1.8.0-l10n-Release/Linux_2.4.21-37.EL_Depend/mozilla/browser/locales/../../../l10n/ga-IE/browser/firefox-l10n.js"

pref("general.useragent.locale", "ga-IE");
